@@ -10,6 +10,7 @@ from django.utils.translation import ugettext as _
 from drf_auth_service.common.enums import RegisterType, SocialTypes, LogsType
 from drf_auth_service.common.helpers import generate_token, generate_code
 from drf_auth_service.common.models import BaseModel
+from drf_auth_service.settings import settings
 
 
 class Service(models.Model):
@@ -35,14 +36,14 @@ class AbstractSSOUser(AbstractBaseUser):
 
     @property
     def is_confirmed(self):
-        if self.activation_code.filter(key_type=ActivationCode.CodeTypes.CONFIRM_ACCOUNT).first() is None:
+        if self.activation_code.filter(key_type=ActivationCode.CodeTypes.CONFIRM_ACCOUNT).first() is None:  # noqa
             return True
         return False
 
     @property
     def is_blocked(self):
         try:
-            if self.block:
+            if self.block:  # noqa
                 return True
         except ObjectDoesNotExist:
             return False
@@ -139,11 +140,14 @@ class ActivationCode(models.Model):
 
     @staticmethod
     def create_token(user, key_type, for_phone=False):
-        password_reset_token_validation_time = 24
-        now_minus_expiry_time = timezone.now() - timedelta(hours=password_reset_token_validation_time)
-        ActivationCode.clear_expired(now_minus_expiry_time, key_type=key_type)
-        key = generate_code() if for_phone else generate_token()
-        token, is_created = ActivationCode.objects.update_or_create(user=user, key_type=key_type, defaults={'key': key})
+        if settings.DEBUG_MODE:
+            key = settings.DEBUG_KEY
+        else:
+            password_reset_token_validation_time = 24
+            now_minus_expiry_time = timezone.now() - timedelta(hours=password_reset_token_validation_time)
+            ActivationCode.clear_expired(now_minus_expiry_time, key_type=key_type)
+            key = generate_code() if for_phone else generate_token()
+        token, _ = ActivationCode.objects.update_or_create(user=user, key_type=key_type, defaults={'key': key})
         return token
 
 
