@@ -22,15 +22,15 @@ class ReturnUserBaseSerializer(serializers.ModelSerializer):
         fields = ('id', 'username', 'service', 'is_blocked', 'user_social_identifier', 'is_confirmed')
 
 
-class UserConfirmSerializer(serializers.Serializer):
+class UserConfirmSerializer(serializers.Serializer): # noqa
     token = serializers.CharField(required=True, allow_null=False, allow_blank=False,
                                   label="Token to confirm user")
 
-    def validate_token(self, token):
+    def validate_token(self, token): # noqa
         return validate_token_by_type(token, ActivationCode.CodeTypes.CONFIRM_ACCOUNT)
 
 
-class UserSetPasswordSerializer(serializers.Serializer):
+class UserSetPasswordSerializer(serializers.Serializer): # noqa
     password = serializers.CharField(label="Password", required=True, allow_null=False, allow_blank=False)
     confirm_password = serializers.CharField(label="Confirm password", required=True,
                                              allow_null=False, allow_blank=False)
@@ -42,5 +42,5 @@ class UserSetPasswordSerializer(serializers.Serializer):
         return data
 
 
-class BlockUserSerializer(serializers.Serializer):
+class BlockUserSerializer(serializers.Serializer): # noqa
     reason = serializers.CharField(required=True)
